Welcome to RAMLfications's documentation!
=========================================

Release v\ |release| (:doc:`What's new? <changelog>`).


.. include:: intro.rst
      :start-after: begin


User's Guide
============

.. toctree::

   installation
   usage
   extendedusage
   config
   api


Project Information
===================

.. toctree::
   :maxdepth: 1
   :titlesonly:

   changelog
   license
   contributing



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

